@@ -58,6 +58,5 @@ st_make_valid.sfc = function(x) {
 
 #' @export
 st_make_valid.sf = function(x) {
-	st_geometry(x) = st_make_valid(st_geometry(x))
-	x
+	st_set_geometry(x, st_make_valid(st_geometry(x)))
 }
