@@ -9,13 +9,17 @@ test_that("st_transform works", {
   sp = as(s, "Spatial")
   sp.tr = spTransform(sp, CRS("+init=epsg:3857"))
   s2.tr = st_as_sfc(sp.tr)
-  attr(s1.tr, "crs")$proj4string = ""
-  attr(s2.tr, "crs")$proj4string = ""
+  #attr(s1.tr, "crs")$proj4string = ""
+  #attr(s2.tr, "crs")$proj4string = ""
+  st_crs(s1.tr) = NA_crs_
+  st_crs(s2.tr) = NA_crs_
   expect_equal(s1.tr, s2.tr)
 
   toCrs = 3857
   s1.tr = st_transform(s, toCrs)
-  attr(s1.tr, "crs")$proj4string = ""
+  #attr(s1.tr, "crs")$proj4string = ""
+  st_crs(s1.tr) = NA_crs_
+  st_crs(s2.tr) = NA_crs_
   expect_equal(s1.tr, s2.tr)
 
   expect_silent({
@@ -32,3 +36,7 @@ test_that("gdal can be loaded, unloaded, and loaded", {
   }
   )
 })
+
+test_that("st_wrap_dateline works", {
+	expect_silent(x <- st_wrap_dateline(st_sfc(st_linestring(rbind(c(-179,0),c(179,0))), crs = 4326)))
+})
